@@ -25,7 +25,7 @@ def formatTemplate(detail, template=defaultMarkdown):
 	template = template.format(
 		PROJECT_NAME=detail.get('PROJECT_NAME'),
 		TITLE=detail.get('title'),
-		MESSAGE=detail.message,
+		MESSAGE=detail.get('message').get('formatted'),
 		URL=detail.get('URL'),
 		ENV=detail.get('environment'),
 		PLATFORM=detail.get('platform'),
